Package: vDiveR
Type: Package
Title: Visualization of Viral Protein Sequence Diversity Dynamics
Version: 2.2.1
Authors@R: c(
    person("Pendy", "Tok", email = "pendytok0518@gmail.com", role = c("aut", "cre")),
    person("Li Chuin", "Chong", role = "aut"),
    person("Evgenia", "Chikina", role = "aut"),
    person("Yin Cheng", "Chen", role = "aut"),
    person("Mohammad Asif", "Khan", role = "aut"))
Description: To ease the visualization of outputs from Diversity Motif Analyser ('DiMA';
    <https://github.com/BVU-BILSAB/DiMA>). 'vDiveR' allows visualization of the diversity 
    motifs (index and its variants – major, minor and unique) for elucidation of 
    the underlying inherent dynamics. Please refer <https://vdiver-manual.readthedocs.io/en/latest/>
    for more information.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Imports: dplyr, ggplot2, ggpubr, grid, ggtext, magrittr, tidyr,
        stringr, rlang, rentrez, scales, utils, maps, cowplot,
        stringdist, patchwork
RoxygenNote: 7.3.3
Depends: R (>= 2.10)
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-23 10:51:21 UTC; pendy
Author: Pendy Tok [aut, cre],
  Li Chuin Chong [aut],
  Evgenia Chikina [aut],
  Yin Cheng Chen [aut],
  Mohammad Asif Khan [aut]
Maintainer: Pendy Tok <pendytok0518@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-23 12:40:02 UTC
Built: R 4.6.0; ; 2026-07-23 14:39:25 UTC; unix
