# Generated by roxygen2: do not edit by hand

export(concat_conserved_kmer)
export(json2csv)
export(metadata_extraction)
export(plot_conservation_level)
export(plot_correlation)
export(plot_dynamics_protein)
export(plot_dynamics_proteome)
export(plot_entropy)
export(plot_time)
export(plot_world_map)
importFrom(cowplot,draw_label)
importFrom(cowplot,draw_plot)
importFrom(cowplot,ggdraw)
importFrom(cowplot,plot_grid)
importFrom(dplyr,"%>%")
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,right_join)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(dplyr,vars)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,map_data)
importFrom(ggplot2,margin)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,position_jitter)
importFrom(ggplot2,scale_color_grey)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_date)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_log10)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,vars)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(ggpubr,annotate_figure)
importFrom(ggpubr,ggarrange)
importFrom(ggpubr,text_grob)
importFrom(ggtext,geom_richtext)
importFrom(grid,unit)
importFrom(magrittr,"%>%")
importFrom(maps,map)
importFrom(patchwork,plot_layout)
importFrom(patchwork,wrap_plots)
importFrom(rentrez,entrez_fetch)
importFrom(rentrez,entrez_search)
importFrom(rlang,":=")
importFrom(scales,date_format)
importFrom(scales,math_format)
importFrom(scales,trans_breaks)
importFrom(scales,trans_format)
importFrom(stats,aggregate)
importFrom(stringdist,stringdist)
importFrom(stringr,str_extract)
importFrom(stringr,str_sub)
importFrom(stringr,str_to_title)
importFrom(tidyr,replace_na)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
